## Version v0.1.2 (2019/01/21)


### Pull Requests Merged

#### Bugs fixed

* [PR 23](https://github.com/pytroll/trollmoves/pull/23) - Fix the persistant ftp connection

#### Features added

* [PR 24](https://github.com/pytroll/trollmoves/pull/24) - Switch to versioneer
* [PR 22](https://github.com/pytroll/trollmoves/pull/22) - Remove Develop branch
* [PR 21](https://github.com/pytroll/trollmoves/pull/21) - Feature persistent connection
* [PR 17](https://github.com/pytroll/trollmoves/pull/17) - Feature posttroll serve
* [PR 16](https://github.com/pytroll/trollmoves/pull/16) - persistent ssh/scp connection
* [PR 15](https://github.com/pytroll/trollmoves/pull/15) - Make ftp connections persistent for 30 seconds
* [PR 14](https://github.com/pytroll/trollmoves/pull/14) - Feature client unpack
* [PR 13](https://github.com/pytroll/trollmoves/pull/13) - Improve error handling in SCPMover
* [PR 12](https://github.com/pytroll/trollmoves/pull/12) - Add support for Python 3
* [PR 11](https://github.com/pytroll/trollmoves/pull/11) - Added argument option disable-backlog
* [PR 8](https://github.com/pytroll/trollmoves/pull/8) - Introducing 'info' request

In this release 12 pull requests were closed.
